@@ -354,7 +354,7 @@ def bytes_iter_skip(
     /, 
     size: int = -1, 
     callback: None | Callable[[int], Any] = None, 
-) -> Iterator[memoryview | Buffer]:
+) -> Iterator[Buffer]:
     it = iter(it)
     if size == 0:
         return it
@@ -378,7 +378,7 @@ async def bytes_async_iter_skip(
     /, 
     size: int = -1, 
     callback: None | Callable[[int], Any] = None, 
-) -> AsyncIterator[memoryview | Buffer]:
+) -> AsyncIterator[Buffer]:
     it = aiter(ensure_aiter(it))
     if size == 0:
         return it
@@ -604,7 +604,7 @@ def bytes_ensure_part_iter(
     it: Iterable[Buffer], 
     /, 
     partsize: int = COPY_BUFSIZE, 
-) -> Iterator[Buffer | memoryview]:
+) -> Iterator[Buffer]:
     n = partsize
     for b in it:
         m = memoryview(b)
@@ -632,7 +632,7 @@ async def bytes_ensure_part_async_iter(
     it: Iterable[Buffer] | AsyncIterable[Buffer], 
     /, 
     partsize: int = COPY_BUFSIZE, 
-) -> AsyncIterator[Buffer | memoryview]:
+) -> AsyncIterator[Buffer]:
     n = partsize
     async for b in ensure_aiter(it):
         m = memoryview(b)
